package com.ruoyi.manage.mapper;

import java.util.List;
import com.ruoyi.manage.domain.RecordInspectionImg;
import org.springframework.stereotype.Repository;
/**
 * 巡检历史图片Mapper接口
 *
 * @author wangh
 * @date 2024-09-27
 */
@Repository
public interface RecordInspectionImgMapper
{
    /**
     * 查询巡检历史图片
     *
     * @param inspectionId 巡检历史图片主键
     * @return 巡检历史图片
     */
    public RecordInspectionImg selectRecordInspectionImgByInspectionId(Long inspectionId);

    /**
     * 查询巡检历史图片列表
     *
     * @param recordInspectionImg 巡检历史图片
     * @return 巡检历史图片集合
     */
    public List<RecordInspectionImg> selectRecordInspectionImgList(RecordInspectionImg recordInspectionImg);

    /**
     * 新增巡检历史图片
     *
     * @param recordInspectionImg 巡检历史图片
     * @return 结果
     */
    public int insertRecordInspectionImg(RecordInspectionImg recordInspectionImg);

    /**
     * 修改巡检历史图片
     *
     * @param recordInspectionImg 巡检历史图片
     * @return 结果
     */
    public int updateRecordInspectionImg(RecordInspectionImg recordInspectionImg);

    /**
     * 删除巡检历史图片
     *
     * @param inspectionId 巡检历史图片主键
     * @return 结果
     */
    public int deleteRecordInspectionImgByInspectionId(Long inspectionId);

    /**
     * 批量删除巡检历史图片
     *
     * @param inspectionIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordInspectionImgByInspectionIds(String[] inspectionIds);
}
